@@ -5,4 +5,4 @@ int gdb_send_packet(int fd, char* data);
 int gdb_recv_packet(int fd, char** buffer);
 int gdb_check_for_interrupt(int fd);
 
-#endif
+#endif // _GDB_REMOTE_H_
